shared float4x4 mWorldViewProj	: 	WORLDVIEWPROJ;
shared float4x4 mWorldView			: 	WORLDVIEW;
shared float4x4 mProj				:	PROJ;

// Base texture
shared texture tBase;
sampler2D baseTexture = sampler_state
{
	Texture = (tBase);
	MipFilter = LINEAR;
	MinFilter = LINEAR;
	MagFilter = LINEAR;
	AddressU = WRAP;
	AddressV = WRAP;
};

struct VS_INPUT
{
	float3 pos : POSITION;
	float2 tex : TEXCOORD0;
	float2 size : TEXCOORD1;
	float3 tex2 : TEXCOORD2;
	float4 color : COLOR;
};

struct VS_OUTPUT
{
	float4 pos : POSITION;
	float2 tex : TEXCOORD0;
	float4 color : COLOR;
	float3 tex2 : TEXCOORD1;
};

VS_OUTPUT VS(VS_INPUT input)
{
	VS_OUTPUT Out = (VS_OUTPUT)0;

	float4 viewSpace = mul(float4(input.pos, 1.f), mWorldView);
	viewSpace += float4(viewSpace.w*input.size.x,viewSpace.w*input.size.y, 0, 0);
	Out.pos = mul(viewSpace, mProj);
	Out.tex = input.tex;
	Out.tex2 = input.tex2;
	Out.color = input.color;

	return Out;
}

float4 PS(VS_OUTPUT input) : COLOR
{
	return input.color * ((1.f - input.tex2.z) * tex2D(baseTexture, input.tex) + 
	input.tex2.z * tex2D(baseTexture, float2(input.tex2.x, input.tex2.y)));
}

technique DefaultTechnique
{
	pass P0
	{
		CullMode = None;
		Clipping = false;
		AlphaBlendEnable = true;
		ZWriteEnable = false;
		ZEnable = true;
		SrcBlend = SrcAlpha;
		DestBlend = One;
		Lighting = false;
		VertexShader = compile vs_1_1 VS();
		PixelShader  = compile ps_1_4 PS();
	}  
}


