/** @file
	@author Jukka Jylnki

	This work is copyrighted material and may NOT be used for any kind of commercial or 
	personal advantage and may NOT be copied or redistributed without prior consent
	of the author(s). 

	Renders the object with its diffuse color, no lighting.
*/

string ParamID = "0x00";

// transformations
shared float4x4 mWorldViewProj : 	WORLDVIEWPROJ; //: WORLDVIEWPROJECTION;
shared float4x4 mWorld : 	WORLD;
shared float4x4 mWorldView : 	WORLDVIEW;
shared float4x4 mView : 	VIEW;

shared float4 cDiffuse : COLOR0
<
	string UIName = "Diffuse";
> = float4(0.8f, 0.8f, 0.8f, 1.f);

shared texture tBase
<
	string UIName = "Base Texture";
>;

sampler DiffuseSampler = 
sampler_state
{
    Texture = (tBase);
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

struct VS_INPUT
{
	float3 pos : POSITION0;
	float2 uv : TEXCOORD0;
};

struct VS_OUTPUT
{
	float4 pos : POSITION0;
	float2 uv : TEXCOORD0;
};

VS_OUTPUT VSMain(VS_INPUT In)
{
	VS_OUTPUT Out = (VS_OUTPUT)0;
	
	// transform pos to proj space
	Out.pos = mul(float4(In.pos,1),mWorldViewProj);
	Out.uv = In.uv;
	return Out;	
}	

float4 PSMain(VS_OUTPUT In) : COLOR
{
	return cDiffuse * float4(tex2D(DiffuseSampler, In.uv).xyz, 1.f);
}

technique DefaultTechnique
{
    pass P0
    {
        VertexShader = compile vs_2_0 VSMain();
        PixelShader  = compile ps_2_0 PSMain();
    }  
}
