/** @file
	@author Jukka Jylnki

	This work is copyrighted material and may NOT be used for any kind of commercial or 
	personal advantage and may NOT be copied or redistributed without prior consent
	of the author(s). 
*/
#include "skinning.fx"

// transformations
shared float4x4 mWorldViewProj : 	WORLDVIEWPROJ;

struct VS_INPUT
{
	float3 pos : POSITION0;

#ifdef SKINNING
	float3 BlendWeights    : BLENDWEIGHT;
	float4 BlendIndices    : BLENDINDICES;
#endif
};

struct VS_OUTPUT
{
	float4 pos : POSITION0;

	float2 depth : TEXCOORD0;
};

VS_OUTPUT VSMain(VS_INPUT In)
{
	VS_OUTPUT Out = (VS_OUTPUT)0;

	// transform pos to proj space
#ifdef SKINNING
	float4 p = SkinVertex(In.BlendWeights, In.BlendIndices, float4(In.pos.xyz, 1));
	Out.pos = mul(p, mWorldViewProj);
#else
	Out.pos = mul(float4(In.pos,1),mWorldViewProj);
#endif

	Out.depth.xy = Out.pos.zw;
	return Out;	
}	

float4 PSMain(VS_OUTPUT In) : COLOR
{
	return In.depth.x / In.depth.y; // z/w
}

technique DefaultTechnique
{
	pass P0
	{
		VertexShader = compile vs_2_0 VSMain();
		PixelShader  = compile ps_2_0 PSMain();
	}
}