/** @file
	@author Jukka Jylnki

	This work is copyrighted material and may NOT be used for any kind of commercial or 
	personal advantage and may NOT be copied or redistributed without prior consent
	of the author(s). 

	A debug effect that renders the object texcoords as (R,G) */

// transformations
shared float4x4 mWorldViewProj : 	WORLDVIEWPROJ;
shared float4x4 mWorld : 	WORLD;
shared float4x4 mWorldView : 	WORLDVIEW;
shared float4x4 mView : 	VIEW;

struct VS_INPUT
{
	float3 pos : POSITION0;
	float2 tex : TEXCOORD0;
};

struct VS_OUTPUT
{
	float4 pos : POSITION0;
	float2 tex : TEXCOORD0;
};

VS_OUTPUT VSMain(VS_INPUT In)
{
	VS_OUTPUT Out = (VS_OUTPUT)0;
	
	// transform pos to proj space
	Out.pos = mul(float4(In.pos,1),mWorldViewProj);
	
	// pos in world space
	float4 pos = mul(float4(In.pos,1),mWorld);
	
	Out.tex = In.tex;

	return Out;	
}	

float4 PSMain(VS_OUTPUT In) : COLOR
{
	return float4(frac(abs(In.tex.xy)), 0, 1);
}

technique DefaultTechnique
{
    pass P0
    {
        VertexShader = compile vs_2_0 VSMain();
        PixelShader  = compile ps_2_0 PSMain();
    }  
}
